@@ -20,7 +20,6 @@
 import logging
 import os
 from datetime import date, timedelta
-from pathlib import Path
 from typing import List, Optional
 
 import click
@@ -30,21 +29,56 @@ from srcopsmetrics.bot_knowledge import analyse_projects
 from srcopsmetrics.enums import EntityTypeEnum, StoragePath
 from srcopsmetrics.github_knowledge import GitHubKnowledge
 from srcopsmetrics.kebechet_metrics import KebechetMetrics
-from srcopsmetrics.metrics import Metrics
-from srcopsmetrics.storage import KnowledgeStorage
+from srcopsmetrics.kebechet_sli_slo_metrics import KebechetSliSloMetrics
 
 _LOGGER = logging.getLogger("aicoe-src-ops-metrics")
 logging.basicConfig(level=logging.INFO)
 
 
-def get_entities_as_list(entities_raw: Optional[str]) -> List[str]:
+def _parse_entities(entities_raw: Optional[str]) -> List[str]:
     """Get passed entities as list."""
     if entities_raw and entities_raw != "":
-        return entities_raw.split(",")
+        return [e.strip() for e in entities_raw.split(",")]
 
     return []
 
 
+def _parse_repos(repository: Optional[str], organization: Optional[str]):
+    repos = []
+
+    if repository:
+        for rep in repository.split(","):
+            repos.extend(GitHubKnowledge().get_repositories(repository=rep.strip()))
+    if organization:
+        repos.extend(GitHubKnowledge().get_repositories(organization=organization))
+
+    return repos
+
+
+def _check_env_vars(is_local: bool):
+    if not is_local:
+        ceph_needed_vars = ["CEPH_KEY_ID", "CEPH_SECRET_KEY", "CEPH_BUCKET_PREFIX", "S3_ENDPOINT_URL", "CEPH_BUCKET"]
+        missing = []
+        for env in ceph_needed_vars:
+            if os.getenv(env) is None:
+                missing.append(env)
+
+        if len(missing) > 0:
+            _LOGGER.warning("--is_local option is not set but Ceph environment variables are missing.")
+            _LOGGER.warning("Missing: " + ",".join(env))
+
+    if os.getenv("GITHUB_ACCESS_TOKEN") is None:
+        _LOGGER.warning(
+            "Missing GITHUB_ACCESS_TOKEN environment variable; The rate limit of GitHub API request will be limited"
+        )
+
+
+def _set_env_vars(is_local: bool, knowledge_path: Optional[str], merge_path: Optional[str]):
+    os.environ["IS_LOCAL"] = "True" if is_local else "False"
+    os.environ[StoragePath.LOCATION_VAR.value] = knowledge_path
+    os.environ[StoragePath.MERGE_LOCATION_ENVVAR_NAME.value] = merge_path
+
+
 @click.command()
 @click.option(
     "--repository",
@@ -70,13 +104,6 @@ def get_entities_as_list(entities_raw: Optional[str]) -> List[str]:
             Storage location is {StoragePath.KNOWLEDGE.value}
             Removes all previously processed storage""",
 )
-@click.option(
-    "--process-knowledge",
-    "-p",
-    is_flag=True,
-    help=f"""Process knowledge into more explicit information from collected knowledge.
-            Storage location is {StoragePath.PROCESSED.value}""",
-)
 @click.option(
     "--is-local",
     "-l",
@@ -96,16 +123,6 @@ def get_entities_as_list(entities_raw: Optional[str]) -> List[str]:
             """
     + "\n".join([entity.value for entity in EntityTypeEnum]),
 )
-@click.option(
-    "--visualize-statistics",
-    "-v",
-    is_flag=True,
-    help="""Visualize statistics on the project repository knowledge collected.
-            Dash application is launched and can be accesed at http://127.0.0.1:8050/""",
-)
-@click.option(
-    "--reviewer-reccomender", "-R", is_flag=True, help="Assign reviewers based on previous knowledge collected."
-)
 @click.option(
     "--knowledge-path",
     "-k",
@@ -125,7 +142,7 @@ def get_entities_as_list(entities_raw: Optional[str]) -> List[str]:
 )
 @click.option(
     "--metrics",
-    "-m",
+    "-x",
     is_flag=True,
     required=False,
     help="""Launch Metrics Calculation for specified repository.""",
@@ -144,67 +161,61 @@ def get_entities_as_list(entities_raw: Optional[str]) -> List[str]:
     default=StoragePath.MERGE_PATH.value,
     help="""Data/statistics are stored under this path.""",
 )
+@click.option(
+    "--sli-slo",
+    is_flag=True,
+    required=False,
+    help="""Launch sli-slo metrics calculation given repositories. Must be used in conjunction with -t""",
+)
 def cli(
     repository: Optional[str],
     organization: Optional[str],
     create_knowledge: bool,
-    process_knowledge: bool,
     is_local: bool,
     entities: Optional[str],
-    visualize_statistics: bool,
-    reviewer_reccomender: bool,
     knowledge_path: str,
     thoth: bool,
     metrics: bool,
     merge: bool,
     merge_path: str,
+    sli_slo: bool,
 ):
     """Command Line Interface for SrcOpsMetrics."""
-    os.environ["IS_LOCAL"] = "True" if is_local else "False"
-    os.environ[StoragePath.LOCATION_VAR.value] = knowledge_path
-    os.environ[StoragePath.MERGE_LOCATION_ENVVAR_NAME.value] = merge_path
+    _check_env_vars(is_local=is_local)
+    _set_env_vars(is_local=is_local, knowledge_path=knowledge_path, merge_path=merge_path)
 
-    repos = []
-
-    if repository:
-        for rep in repository.split(","):
-            repos.extend(GitHubKnowledge().get_repositories(repository=rep.strip()))
-    if organization:
-        repos.extend(GitHubKnowledge().get_repositories(organization=organization))
-
-    entities_args = get_entities_as_list(entities)
+    repos = _parse_repos(repository=repository, organization=organization)
+    entities_args = _parse_entities(entities)
 
     if create_knowledge:
         analyse_projects(repositories=repos, is_local=is_local, entities=entities_args)
 
-    for project in repos:
-        os.environ["PROJECT"] = project
+    # for project in repos:
+    #     os.environ["PROJECT"] = project
 
     today = date.today()
     yesterday = today - timedelta(days=1)
 
     if thoth:
-        if repository and not merge:
-            kebechet_metrics = KebechetMetrics(repository=repos[0], day=yesterday, is_local=is_local)
-            kebechet_metrics.evaluate_and_store_kebechet_metrics()
+        _LOGGER.info("#### Launching thoth data analysis ####")
 
-        if metrics:
-            repo_metrics = Metrics(repository=repos[0], visualize=visualize_statistics)
+        if repos and not merge and not sli_slo:
+            for repo in repos:
+                _LOGGER.info("Creating metrics for repository %s" % repo)
+                kebechet_metrics = KebechetMetrics(repository=repo, day=yesterday, is_local=is_local)
+                kebechet_metrics.evaluate_and_store_kebechet_metrics()
 
-            repo_metrics.get_metrics_outliers_pull_requests()
-            repo_metrics.get_metrics_outliers_issues()
-
-            scores = repo_metrics.evaluate_scores_for_pull_requests()
-
-            path = Path(f"./srcopsmetrics/metrics/{repos[0]}/pr_scores.json")
-            KnowledgeStorage(is_local=is_local).save_knowledge(file_path=path, data=scores)
-
-            scores_issues = repo_metrics.evaluate_scores_for_issues()
-            path = Path(f"./srcopsmetrics/metrics/{repos[0]}/issue_scores.json")
-            KnowledgeStorage(is_local=is_local).save_knowledge(file_path=path, data=scores_issues)
+        if sli_slo:
+            _LOGGER.info("#### Inspecting kebechet repositories and creating SLI/SLO metrics ####")
+            keb_sli_slo = KebechetSliSloMetrics(repositories=repos, is_local=is_local)
+            keb_sli_slo.evaluate_and_store_sli_slo_kebechet_metrics()
+            # keb_sli_slo.evaluate_and_store_usage_timestamp_sli_slo_kebechet_metrics()
 
     if merge:
         if thoth:
+            _LOGGER.info("Merging kebechet metrics for %s" % yesterday)
+
+            ## TODO: merge action omitted ?
             KebechetMetrics.merge_kebechet_metrics_per_day(day=yesterday, is_local=is_local)
         else:
             raise NotImplementedError
