@@ -45,5 +45,13 @@ class StatisticalQuantityEnum(Enum):
 class StoragePath(Enum):
     """Enum with predefined storage locations."""
 
-    KNOWLEDGE = "./srcopsmetrics/bot_knowledge/"
-    PROCESSED = "./srcopsmetrics/processed/"
+    DEFAULT = "./srcopsmetrics/"
+    LOCATION_VAR = "KNOWLEDGE_PATH"
+    MERGE_LOCATION_ENVVAR_NAME = "MERGE_PATH"
+    KNOWLEDGE = "bot_knowledge"
+    MERGE = "metrics"
+    PROCESSED = "processed"
+
+    KNOWLEDGE_PATH = DEFAULT + KNOWLEDGE
+    MERGE_PATH = DEFAULT + MERGE
+    PROCESSED_PATH = DEFAULT + PROCESSED
