@@ -18,9 +18,15 @@
 """Exceptions for SrcOpsMetrics."""
 
 
-class MissingPreviousKnowledge(Exception):
+class MissingPreviousKnowledgeError(Exception):
     """An exception when no previous knowledge has been extracted for a project."""
 
 
-class NotKnownEntities(Exception):
+class NotKnownEntitiesError(Exception):
     """An exception when Entities requested are not known."""
+
+    def __init__(self, message, specified_entities, available_entities):
+        """Initialize exception with user specified entities."""
+        allowed = [e.__name__ for e in available_entities]
+        unallowed = [e for e in specified_entities if e not in allowed]
+        super().__init__("Invalid specified entities: %s", unallowed)
